# Table of Contents

- [sap-landscape-discovery-inbox](<./sap-landscape-discovery-inbox.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [SAP Discovery Inbox](<./SAP-Discovery-Inbox.md>)
  - [Overview](<./SAP-Discovery-Inbox/Overview.md>)
  - [Accessing the SAP Discovery Inbox from the Inventory](<./SAP-Discovery-Inbox/Accessing-the-SAP-Discovery-Inbox-from-the-Inventory.md>)
  - [Filtering and Searching in the Discovery Inbox](<./SAP-Discovery-Inbox/Filtering-and-Searching-in-the-Discovery-Inbox.md>)
  - [Linking Discovered Items to Suggested Fact Sheets](<./SAP-Discovery-Inbox/Linking-Discovered-Items-to-Suggested-Fact-Sheets.md>)
  - [Linking Beyond Suggested Fact Sheets](<./SAP-Discovery-Inbox/Linking-Beyond-Suggested-Fact-Sheets.md>)
  - [Linking Discovered Items to Fact Sheets in Bulk](<./SAP-Discovery-Inbox/Linking-Discovered-Items-to-Fact-Sheets-in-Bulk.md>)
  - [Changing Existing Links to Fact Sheets](<./SAP-Discovery-Inbox/Changing-Existing-Links-to-Fact-Sheets.md>)
  - [Rejecting Discovered Items](<./SAP-Discovery-Inbox/Rejecting-Discovered-Items.md>)
  - [Rejecting Discovered Items in Bulk](<./SAP-Discovery-Inbox/Rejecting-Discovered-Items-in-Bulk.md>)
  - [Managing Updates to Reviewed Discovery Items](<./SAP-Discovery-Inbox/Managing-Updates-to-Reviewed-Discovery-Items.md>)
  - [Reviewing Discovered Cloud ALM Items](<./SAP-Discovery-Inbox/Reviewing-Discovered-Cloud-ALM-Items.md>)
  - [Best Practices for Managing Your Inbox](<./SAP-Discovery-Inbox/Best-Practices-for-Managing-Your-Inbox.md>)
  - [Next Steps](<./SAP-Discovery-Inbox/Next-Steps.md>)
  - [Was this page helpful?](<./SAP-Discovery-Inbox/Was-this-page-helpful.md>)
